@@ -80,9 +80,9 @@ static const char* report_dir = "/var/crash";
 
 /* Options */
 int foreground = 0;
-static int assume_online = 0;
 
 #ifndef TEST
+static int assume_online = 0;
 static GOptionEntry option_entries[] = {
     { "foreground", 'f', 0, G_OPTION_ARG_NONE, &foreground, "Run in the foreground", NULL },
     { "assume-online", 'a', 0, G_OPTION_ARG_NONE, &assume_online, "Always assume there is a route to $CRASH_DB_URL.", NULL },
@@ -125,8 +125,10 @@ static const char* acceptable_fields[] = {
     /* add_gdb_info */
     "Registers",
     "Disassembly",
-    "Stacktrace",
-    "ThreadStacktrace",
+    /* We do not need these since we retrace with ddebs on errors */
+    /* "Stacktrace", */
+    /* "ThreadStacktrace", */
+    /* used to repair the StacktraceAddressSignature if it is corrupt */
     "StacktraceTop",
     "AssertionMessage",
     "ProcAttrCurrent",
@@ -712,8 +714,10 @@ void daemonize (void)
     if ((chdir ("/")) < 0)
         exit (EXIT_FAILURE);
 
-    for (i = 0; i < rl.rlim_max && i < 1024; i++)
-        close (i);
+    for (i = 0; i < rl.rlim_max && i < 1024; i++) {
+        if (i != lock_fd)
+            close (i);
+    }
     if ((open ("/dev/null", O_RDWR) != 0) ||
         (dup (0) != 1) ||
         (dup (0) != 2)) {
@@ -756,9 +760,9 @@ exit_if_already_running (void)
 char*
 get_crash_db_url (void)
 {
-    char* url = NULL;
+    const char* url = NULL;
 
-    url = getenv ("CRASH_DB_URL");
+    url = g_getenv ("CRASH_DB_URL");
     if (url == NULL)
         return NULL;
 
@@ -920,18 +924,20 @@ main (int argc, char** argv)
     setup_signals ();
     parse_arguments (&argc, &argv);
 
+    if (!foreground) {
+        open_log ();
+        log_msg ("whoopsie " VERSION " starting up.\n");
+    }
+
     if ((crash_db_url = get_crash_db_url ()) == NULL) {
         log_msg ("Could not get crash database location.\n");
         exit (EXIT_FAILURE);
     }
 
-    if (!foreground)
-        open_log ();
-
     /* environment might change report directory and identifier */
     env = g_getenv ("APPORT_REPORT_DIR");
     if (env != NULL && *env != '\0')
-        report_dir = env;
+        report_dir = g_strdup (env);
 
     env = g_getenv ("CRASH_DB_IDENTIFIER");
     if (env != NULL)
@@ -944,7 +950,6 @@ main (int argc, char** argv)
         g_error_free (err);
         err = NULL;
         crash_db_submit_url = strdup (crash_db_url);
-
     } else {
         crash_db_submit_url = g_strdup_printf ("%s/%s", crash_db_url,
                                                whoopsie_identifier);
@@ -960,8 +965,11 @@ main (int argc, char** argv)
     }
     exit_if_already_running ();
 
-    if (!foreground)
+    if (!foreground) {
+        close_log ();
         daemonize ();
+        open_log();
+    }
 
 #if GLIB_MAJOR_VERSION <= 2 && GLIB_MINOR_VERSION < 35
     /* Deprecated in glib 2.35/2.36. */
